==> mysql-workbench-community-8.0.12-src.tar.gz: mysql-workbench-community-8.0.12-src/frontend/mac/components/MCollectionViewItem.m <==
/*
 * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
 */

#import "MCollectionViewItem.h"
#import "MCollectionViewItemView.h"

@implementation MCollectionViewItem


- (id)copy
{
  id other = [super copy];
  [other view].menu = self.view.menu;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)[other view];
  itemView.owner = other;
  return other;
}


- (void)setView: (NSView*)view
{
  super.view = view;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)view;
  itemView.owner = self;
}


- (void)setSelected:(BOOL)flag 
{
  super.selected = flag;
  
  MCollectionViewItemView* itemView= (MCollectionViewItemView*)self.view;
  if ([itemView isKindOfClass:[MCollectionViewItemView class]]) 
  {
    itemView.selected = flag;
    [itemView setNeedsDisplay:YES];
  }
}

@end

==> mysql-workbench-community-8.0.33-src.tar.gz: mysql-workbench-community-8.0.33-src/frontend/mac/components/MCollectionViewItem.m <==
/*
 * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
 */

#import "MCollectionViewItem.h"
#import "MCollectionViewItemView.h"

//----------------------------------------------------------------------------------------------------------------------

@implementation MCollectionViewItem

- (id)copy {
  id other = [super copy];
  [other view].menu = self.view.menu;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)[other view];
  itemView.owner = other;
  return other;
}

//----------------------------------------------------------------------------------------------------------------------

- (void)setView: (NSView*)view {
  super.view = view;
  MCollectionViewItemView *itemView = (MCollectionViewItemView *)view;
  itemView.owner = self;
}

//----------------------------------------------------------------------------------------------------------------------

- (void)setSelected:(BOOL)flag {
  super.selected = flag;
  
  MCollectionViewItemView* itemView = (MCollectionViewItemView*)self.view;
  if ([itemView isKindOfClass: [MCollectionViewItemView class]]) {
    itemView.selected = flag;
    [itemView setNeedsDisplay:YES];
  }
}

@end

//----------------------------------------------------------------------------------------------------------------------
